AdStyles class
Constructors
-
AdStyles({String? ctaColor, String? ctaTextColor, AdCTAConfig? ctaConfig, AdBackground? background, AdTextConfig? title, AdTextConfig? description, String? androidChannelId, String? sound, int? appleBadge, int? expiresIn, Map<
String, String> ? customData}) -
AdStyles.fromJson(Map<
String, dynamic> json) -
factory
Properties
- androidChannelId → String?
-
final
- appleBadge → int?
-
final
- background → AdBackground?
-
final
- ctaColor → String?
-
final
- ctaConfig → AdCTAConfig?
-
final
- ctaTextColor → String?
-
final
-
customData
→ Map<
String, String> ? -
final
- description → AdTextConfig?
-
final
- expiresIn → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sound → String?
-
final
- title → AdTextConfig?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited