AiSpeechOptions class

Constructors

AiSpeechOptions({required String text, String? voice, String? model, double? speed, String? stepId})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
model String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed double?
final
stepId String?
final
text String
final
voice String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited