CommunityMessages class

Snackbar and dialog fallbacks from CommunityAppearanceRegistry.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

commentAdded String
no setter
commentCreateFailed String
no setter
commentEmpty String
no setter
commentLoadFailed String
no setter
errorGeneric String
no setter
likeCommentFailed String
no setter
likeFailed String
no setter
loginRequired String
no setter
loginRequiredComment String
no setter
loginRequiredLike String
no setter