SmartLinksAiGateway class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

chat(AiChatOptions options) Future<AiProcessResponse>
image(AiImageOptions options) Future<AiProcessResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process(AiProcessInstructions instructions, {Map<String, AiFileUpload>? files}) Future<AiProcessResponse>
runPipeline(AiProcessInstructions instructions, {Map<String, AiFileUpload>? files}) Future<AiProcessResponse>
speech(AiSpeechOptions options) Future<AiProcessResponse>
toString() String
A string representation of this object.
inherited
transcribe(AiTranscribeOptions options) Future<AiProcessResponse>
vision(AiVisionOptions options) Future<AiProcessResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance SmartLinksAiGateway
final