SmartLinksCore class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

client SmartLinksClient
no setter
config SmartLinksConfig
no setter
isInitialized bool
no setter

Static Methods

initialize({required String apiKey, bool isDebug = false, String baseUrlV1 = 'https://smartlinks.live/api/v1', String baseUrlV2 = 'https://smartlinks.live/api/v2', String? firebaseProject}) Future<void>
requireInitialized() → void
resetForTest() → void
Resets all core state. For tests only.