SmartLinksNativeApi class
Delegates feature API calls to native SmartLinks SDK via the Flutter bridge.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
Static Methods
-
createComment(
{required String postId, required String content, required String authToken, String? parentId}) → Future< Map< String, dynamic> ?> -
createPost(
{required String communityId, required String title, required String content, required String authToken}) → Future< Map< String, dynamic> ?> -
fetchActiveNotificationAd(
{int? appId, String? language, bool isDebug = false}) → Future< Map< String, dynamic> ?> -
fetchAds(
{String? type}) → Future< Map< String, dynamic> ?> -
fetchApps(
) → Future< Map< String, dynamic> ?> -
generateLink(
String route, Map< String, dynamic> ? params, bool shortLink) → Future<String?> -
getAppUserId(
) → Future< String?> -
getBlogPost(
String slug) → Future< Map< String, dynamic> ?> -
getBlogs(
{int page = 1, String? search}) → Future< Map< String, dynamic> ?> -
getComments(
{required String postId, String? authToken}) → Future< Map< String, dynamic> ?> -
getCommunities(
) → Future< Map< String, dynamic> ?> -
getCommunity(
) → Future< Map< String, dynamic> ?> -
getPosts(
{required int communityId, String? authToken}) → Future< Map< String, dynamic> ?> -
initializeNative(
{required String apiKey, bool isDebug = false}) → Future< bool> - Initializes the native SmartLinks SDK (Android/iOS). No-op on web/desktop.
-
listenForDeepLinks(
void onDeepLink(Map arguments)) → Future< void> -
processAi(
{required String instructionsJson, Map< String, String> files = const {}}) → Future<Map< String, dynamic> ?> -
redeemPromoCode(
String code) → Future< Map< String, dynamic> ?> -
registerDevice(
{required String fcmToken, String? platform, String? deviceType, String? appVersion, String? language}) → Future< Map< String, dynamic> ?> -
requestPendingDeepLink(
) → Future< void> -
sendEvent(
String eventName, Map< String, dynamic> ? properties) → Future<void> -
submitFeedback(
{required String content, required String platform, required String version, String? name, String? email, bool isPremium = false, String? attachmentPath}) → Future< Map< String, dynamic> ?> -
toggleCommentLike(
{required String commentId, required String authToken}) → Future< Map< String, dynamic> ?> -
togglePostLike(
{required int postId, required String authToken}) → Future< Map< String, dynamic> ?> -
trackAdClick(
int adId) → Future< bool> -
trackAdImpression(
int adId) → Future< bool> -
trackNotificationAdClick(
int adId) → Future< bool> -
trackNotificationAdImpression(
int adId) → Future< bool> -
validatePromoCode(
String code) → Future< Map< String, dynamic> ?> -
verifyApplePurchase(
{required String receiptData}) → Future< Map< String, dynamic> ?> -
verifyGooglePurchase(
{required String productId, required String token}) → Future< Map< String, dynamic> ?>