SmartLinksPushHandler class

FCM push notification ads. Requires the host app to call Firebase.initializeApp.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isEnabled bool
no setter

Static Methods

enable({int? appId}) Future<void>
Enables push notification ads after SmartLinks.initialize.
handleBackgroundMessage(RemoteMessage message) Future<void>
handleForegroundMessage(RemoteMessage message) Future<void>
initialize({String? apiKey, int? appId, String? appUserId}) Future<void>
processNotificationPayload(String? payload) Future<void>