SmartLinksNavigator class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getController<
T extends GetxController> () → T -
getCurrentPageName(
) → String? -
goBack<
T> ([T? result]) → void -
goHome(
) → void -
initializeControllers(
) → void -
isControllerRegistered<
T> () → bool -
openBlogs(
{Transition transition = Transition.rightToLeft, Widget bannerAd()?, SmartLinksTheme? theme, BlogsStrings? blogsStrings}) → Future -
openCommunities(
{Transition transition = Transition.rightToLeft, Widget bannerAd()?, SmartLinksTheme? theme, CommunityStrings? communityStrings}) → Future -
openDialog(
Widget dialogBuilder()) → Future -
replacePage(
Widget pageBuilder(), {Transition transition = Transition.rightToLeft}) → Future